@@ -14,9 +14,8 @@ use Filter::Simple;
 use File::Basename;
 use constant IFS => $/;
 
-our $VERSION;
-$VERSION = "1.6_01";
-$VERSION = eval $VERSION;
+use version;
+our $VERSION = version->declare("1.901.0");
 
 FILTER {
     my @grps;
@@ -389,6 +388,9 @@ sub line_to_text {
         local $/ = IFS;
         my $io = IO::Handle->new();
         my $fn = $file eq '-e' ? "/proc/$$/cmdline" : $file;
+        $fn = $0 unless -e $fn;
+        $fn = "$ENV{PWD}/$0" unless -e $fn;
+        $fn = "$ENV{PWD}/$ENV{_}" unless -e $fn;
         open($io, "$fn") or die "Could not open $file: $!";
         my @source = <$io>;
         $file_cache{$file} = \@source;
